#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_DEFINITELY_GREATER_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_DEFINITELY_GREATER_HPP_INCLUDED

#include <nt2/fuzzy/include/functions/scalar/definitely_greater.hpp>

#endif
